import { fromEvent } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { init, connect, disConnect } from 'echarts';
import { Component, ElementRef, Input, Output, EventEmitter, ViewChild, NgZone, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var NgxEchartsComponent = /** @class */ (function () {
    function NgxEchartsComponent(el, ngZone) {
        this.el = el;
        this.ngZone = ngZone;
        this.setOptionConfig = {
            notMerge: true
        };
        this.loadingType = 'default';
        this.autoResize = false;
        this.onInit = new EventEmitter();
        this.onOptionChange = new EventEmitter();
        // events
        this.onClick = new EventEmitter();
        this.onDblClick = new EventEmitter();
        this.onMouseDown = new EventEmitter();
        this.onMouseMove = new EventEmitter();
        this.onMouseUp = new EventEmitter();
        this.onMouseOver = new EventEmitter();
        this.onMouseOut = new EventEmitter();
        this.onGlobalOut = new EventEmitter();
        this.onContextMenu = new EventEmitter();
        // action events
        this.onLegendSelectChanged = new EventEmitter();
        this.onLegendSelected = new EventEmitter();
        this.onLegendUnSelected = new EventEmitter();
        this.onLegendScroll = new EventEmitter();
        this.onDataZoom = new EventEmitter();
        this.onDataRangeSelected = new EventEmitter();
        this.onTimelineChanged = new EventEmitter();
        this.onTimelinePlayChanged = new EventEmitter();
        this.onRestore = new EventEmitter();
        this.onDataViewChanged = new EventEmitter();
        this.onMagicTypeChanged = new EventEmitter();
        this.onGeoSelectChanged = new EventEmitter();
        this.onGeoSelected = new EventEmitter();
        this.onGeoUnSelected = new EventEmitter();
        this.onPieSelectChanged = new EventEmitter();
        this.onPieSelected = new EventEmitter();
        this.onPieUnSelected = new EventEmitter();
        this.onMapSelectChanged = new EventEmitter();
        this.onMapSelected = new EventEmitter();
        this.onMapUnSelected = new EventEmitter();
        this.onAxisAreaSelected = new EventEmitter();
        this.onFocusNodeAdjacency = new EventEmitter();
        this.onUnfocusNodeAdjacency = new EventEmitter();
        this.onBrush = new EventEmitter();
        this.onBrushSelected = new EventEmitter();
        this.onGlobalCursorTaken = new EventEmitter();
        this.onRendered = new EventEmitter();
        this.onFinished = new EventEmitter();
    }
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.ngAfterViewInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.resize$ = fromEvent(window, 'resize')
            .pipe(debounceTime(200))
            .subscribe(function () { return _this.resize(); });
        this.init();
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    NgxEchartsComponent.prototype.ngOnChanges = /**
     * @param {?} changes
     * @return {?}
     */
    function (changes) {
        if (changes["theme"] && !changes["theme"].isFirstChange()) {
            this.dispose();
            this.init();
        }
        if (changes["option"] && !changes["option"].isFirstChange()) {
            if (this.echartsInstance) {
                this.setOption();
            }
        }
        if (changes["group"]) {
            this.toggleGroup(changes["group"]);
        }
        if (changes["loading"]) {
            this.toggleLoading();
        }
    };
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.ngDoCheck = /**
     * @return {?}
     */
    function () {
        this.resize();
    };
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.dispose();
        if (this.resize$) {
            this.resize$.unsubscribe();
        }
    };
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.init = /**
     * @return {?}
     */
    function () {
        var _this = this;
        if (!this.echartsInstance) {
            this.offsetWidth = this.el.nativeElement.offsetWidth;
            this.offsetHeight = this.el.nativeElement.offsetHeight;
            if (!(this.initOpts && this.initOpts.height) && this.offsetHeight === 0) {
                this.el.nativeElement.style.height = '500px';
            }
            this.ngZone.runOutsideAngular(function () {
                _this.echartsInstance = init(_this.host.nativeElement, _this.theme, _this.initOpts);
                _this.onInit.emit(_this.echartsInstance);
                _this.echartsInstance.group = _this.group;
                _this.buildEvent();
                _this.setOption();
            });
        }
        else {
            this.setOption();
        }
    };
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.dispose = /**
     * @return {?}
     */
    function () {
        this.echartsInstance.dispose();
        this.echartsInstance = null;
    };
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.setOption = /**
     * @return {?}
     */
    function () {
        if (this.option) {
            this.echartsInstance.setOption(this.option, this.setOptionConfig);
            this.onOptionChange.emit(this.option);
        }
    };
    /**
     * @param {?} change
     * @return {?}
     */
    NgxEchartsComponent.prototype.toggleGroup = /**
     * @param {?} change
     * @return {?}
     */
    function (change) {
        if (change.previousValue) {
            disConnect(change.previousValue);
        }
        if (change.currentValue) {
            connect(change.currentValue);
        }
    };
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.toggleLoading = /**
     * @return {?}
     */
    function () {
        if (this.echartsInstance) {
            if (this.loading) {
                this.echartsInstance.showLoading(this.loadingType, this.loadingOpts);
            }
            else {
                this.echartsInstance.hideLoading();
            }
        }
    };
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.buildEvent = /**
     * @return {?}
     */
    function () {
        var _this = this;
        // events
        this.echartsInstance.on('click', function (event) { return _this.ngZone.run(function () { return _this.onClick.emit(event); }); });
        this.echartsInstance.on('dblclick', function (event) { return _this.ngZone.run(function () { return _this.onDblClick.emit(event); }); });
        this.echartsInstance.on('mousedown', function (event) { return _this.ngZone.run(function () { return _this.onMouseDown.emit(event); }); });
        this.echartsInstance.on('mousemove', function (event) { return _this.ngZone.run(function () { return _this.onMouseMove.emit(event); }); });
        this.echartsInstance.on('mouseup', function (event) { return _this.ngZone.run(function () { return _this.onMouseUp.emit(event); }); });
        this.echartsInstance.on('mouseover', function (event) { return _this.ngZone.run(function () { return _this.onMouseOver.emit(event); }); });
        this.echartsInstance.on('mouseout', function (event) { return _this.ngZone.run(function () { return _this.onMouseOut.emit(event); }); });
        this.echartsInstance.on('globalout', function (event) { return _this.ngZone.run(function () { return _this.onGlobalOut.emit(event); }); });
        this.echartsInstance.on('contextmenu', function (event) { return _this.ngZone.run(function () { return _this.onContextMenu.emit(event); }); });
        // action events
        this.echartsInstance.on('legendselectchanged', function (event) { return _this.ngZone.run(function () { return _this.onLegendSelectChanged.emit(event); }); });
        this.echartsInstance.on('legendselected', function (event) { return _this.ngZone.run(function () { return _this.onLegendSelected.emit(event); }); });
        this.echartsInstance.on('legendunselected', function (event) { return _this.ngZone.run(function () { return _this.onLegendUnSelected.emit(event); }); });
        this.echartsInstance.on('legendscroll', function (event) { return _this.ngZone.run(function () { return _this.onLegendScroll.emit(event); }); });
        this.echartsInstance.on('datazoom', function (event) { return _this.ngZone.run(function () { return _this.onDataZoom.emit(event); }); });
        this.echartsInstance.on('datarangeselected', function (event) { return _this.ngZone.run(function () { return _this.onDataRangeSelected.emit(event); }); });
        this.echartsInstance.on('timelinechanged', function (event) { return _this.ngZone.run(function () { return _this.onTimelineChanged.emit(event); }); });
        this.echartsInstance.on('timelineplaychanged', function (event) { return _this.ngZone.run(function () { return _this.onTimelinePlayChanged.emit(event); }); });
        this.echartsInstance.on('restore', function (event) { return _this.ngZone.run(function () { return _this.onRestore.emit(event); }); });
        this.echartsInstance.on('dataviewchanged', function (event) { return _this.ngZone.run(function () { return _this.onDataViewChanged.emit(event); }); });
        this.echartsInstance.on('magictypechanged', function (event) { return _this.ngZone.run(function () { return _this.onMagicTypeChanged.emit(event); }); });
        this.echartsInstance.on('geoselectchanged', function (event) { return _this.ngZone.run(function () { return _this.onGeoSelectChanged.emit(event); }); });
        this.echartsInstance.on('geoselected', function (event) { return _this.ngZone.run(function () { return _this.onGeoSelected.emit(event); }); });
        this.echartsInstance.on('geounselected', function (event) { return _this.ngZone.run(function () { return _this.onGeoUnSelected.emit(event); }); });
        this.echartsInstance.on('pieselectchanged', function (event) { return _this.ngZone.run(function () { return _this.onPieSelectChanged.emit(event); }); });
        this.echartsInstance.on('pieselected', function (event) { return _this.ngZone.run(function () { return _this.onPieSelected.emit(event); }); });
        this.echartsInstance.on('pieunselected', function (event) { return _this.ngZone.run(function () { return _this.onPieUnSelected.emit(event); }); });
        this.echartsInstance.on('mapselectchanged', function (event) { return _this.ngZone.run(function () { return _this.onMapSelectChanged.emit(event); }); });
        this.echartsInstance.on('mapselected', function (event) { return _this.ngZone.run(function () { return _this.onMapSelected.emit(event); }); });
        this.echartsInstance.on('mapunselected', function (event) { return _this.ngZone.run(function () { return _this.onMapUnSelected.emit(event); }); });
        this.echartsInstance.on('axisareaselected', function (event) { return _this.ngZone.run(function () { return _this.onAxisAreaSelected.emit(event); }); });
        this.echartsInstance.on('focusNodeAdjacency', function (event) { return _this.ngZone.run(function () { return _this.onFocusNodeAdjacency.emit(event); }); });
        this.echartsInstance.on('unfocusNodeAdjacency', function (event) { return _this.ngZone.run(function () { return _this.onUnfocusNodeAdjacency.emit(event); }); });
        this.echartsInstance.on('brush', function (event) { return _this.ngZone.run(function () { return _this.onBrush.emit(event); }); });
        this.echartsInstance.on('brushselected', function (event) { return _this.ngZone.run(function () { return _this.onBrushSelected.emit(event); }); });
        this.echartsInstance.on('globalcursortaken', function (event) { return _this.ngZone.run(function () { return _this.onGlobalCursorTaken.emit(event); }); });
        this.echartsInstance.on('rendered', function (event) { return _this.ngZone.run(function () { return _this.onRendered.emit(event); }); });
        this.echartsInstance.on('finished', function (event) { return _this.ngZone.run(function () { return _this.onFinished.emit(event); }); });
    };
    /**
     * @return {?}
     */
    NgxEchartsComponent.prototype.resize = /**
     * @return {?}
     */
    function () {
        if (this.autoResize && this.echartsInstance) {
            /** @type {?} */
            var offsetWidth = this.el.nativeElement.offsetWidth;
            /** @type {?} */
            var offsetHeight = this.el.nativeElement.offsetHeight;
            if (this.offsetWidth !== offsetWidth || this.offsetHeight !== offsetHeight) {
                this.offsetWidth = offsetWidth;
                this.offsetHeight = offsetHeight;
                this.echartsInstance.resize();
            }
        }
    };
    NgxEchartsComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngx-echarts',
                    template: "<div #host class=\"echarts-container\"></div>",
                    styles: [":host{display:block;height:100%}.echarts-container{height:100%}"]
                }] }
    ];
    /** @nocollapse */
    NgxEchartsComponent.ctorParameters = function () { return [
        { type: ElementRef },
        { type: NgZone }
    ]; };
    NgxEchartsComponent.propDecorators = {
        theme: [{ type: Input }],
        initOpts: [{ type: Input }],
        option: [{ type: Input }],
        group: [{ type: Input }],
        setOptionConfig: [{ type: Input }],
        loading: [{ type: Input }],
        loadingType: [{ type: Input }],
        loadingOpts: [{ type: Input }],
        autoResize: [{ type: Input }],
        onInit: [{ type: Output }],
        onOptionChange: [{ type: Output }],
        onClick: [{ type: Output }],
        onDblClick: [{ type: Output }],
        onMouseDown: [{ type: Output }],
        onMouseMove: [{ type: Output }],
        onMouseUp: [{ type: Output }],
        onMouseOver: [{ type: Output }],
        onMouseOut: [{ type: Output }],
        onGlobalOut: [{ type: Output }],
        onContextMenu: [{ type: Output }],
        onLegendSelectChanged: [{ type: Output }],
        onLegendSelected: [{ type: Output }],
        onLegendUnSelected: [{ type: Output }],
        onLegendScroll: [{ type: Output }],
        onDataZoom: [{ type: Output }],
        onDataRangeSelected: [{ type: Output }],
        onTimelineChanged: [{ type: Output }],
        onTimelinePlayChanged: [{ type: Output }],
        onRestore: [{ type: Output }],
        onDataViewChanged: [{ type: Output }],
        onMagicTypeChanged: [{ type: Output }],
        onGeoSelectChanged: [{ type: Output }],
        onGeoSelected: [{ type: Output }],
        onGeoUnSelected: [{ type: Output }],
        onPieSelectChanged: [{ type: Output }],
        onPieSelected: [{ type: Output }],
        onPieUnSelected: [{ type: Output }],
        onMapSelectChanged: [{ type: Output }],
        onMapSelected: [{ type: Output }],
        onMapUnSelected: [{ type: Output }],
        onAxisAreaSelected: [{ type: Output }],
        onFocusNodeAdjacency: [{ type: Output }],
        onUnfocusNodeAdjacency: [{ type: Output }],
        onBrush: [{ type: Output }],
        onBrushSelected: [{ type: Output }],
        onGlobalCursorTaken: [{ type: Output }],
        onRendered: [{ type: Output }],
        onFinished: [{ type: Output }],
        host: [{ type: ViewChild, args: ['host',] }]
    };
    return NgxEchartsComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var NgxEchartsModule = /** @class */ (function () {
    function NgxEchartsModule() {
    }
    NgxEchartsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule
                    ],
                    exports: [
                        NgxEchartsComponent,
                    ],
                    declarations: [
                        NgxEchartsComponent,
                    ]
                },] }
    ];
    return NgxEchartsModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */

export { NgxEchartsComponent, NgxEchartsModule };

//# sourceMappingURL=ngx-echarts-net.js.map